@@ -78,8 +78,8 @@ Klamav::Klamav()
 	TQToolTip::add( _tray, i18n( "KlamAV - Virus Protection for TDE" ) );
 	_tray->show();
 
-	DisableFreshklam->setEnabled(FALSE);
-	EnableFreshklam->setEnabled(TRUE);
+	DisableFreshklam->setEnabled(false);
+	EnableFreshklam->setEnabled(true);
 
         config = TDEGlobal::config();
         config->setGroup("Freshklam");
@@ -376,8 +376,8 @@ void Klamav::contextEnableFK() {
 void Klamav::contextDisableFK() {
 
 	freshklam->slotCancel();
-// 	DisableFreshklam->setEnabled(FALSE);
-// 	EnableFreshklam->setEnabled(TRUE);
+// 	DisableFreshklam->setEnabled(false);
+// 	EnableFreshklam->setEnabled(true);
 
 }
 
