@@ -39,8 +39,8 @@ ScanViewer::ScanViewer(TQWidget *parent, const char *name)
     : TQWidget(parent, name)
 {
 
-    scanInProgress = TRUE;
-    multiScan = FALSE;
+    scanInProgress = true;
+    multiScan = false;
 
     //TQGridLayout *layout = new TQGridLayout(this, 6, 3, 10, 4);
     layout = new TQGridLayout(this, 6, 3, 10, 4);
@@ -151,7 +151,7 @@ ScanViewer::ScanViewer(TQWidget *parent, const char *name)
 ScanViewer::~ScanViewer()
 {
 
-    scanCancelled = TRUE;
+    scanCancelled = true;
 
     if ((childproc) && (scanInProgress)){
         delete childproc;
@@ -216,7 +216,7 @@ void ScanViewer::processOutput()
                 //resultview->insertItem(buf.section('\n',j,j));
                 CollectionDB::instance()->insertEvent("Error Found",tmpVirusName,tmpFName);
 
-                errorsEncountered = TRUE;
+                errorsEncountered = true;
                 filesscanned++;
                 if (!(showProgress))
                     status2_label->setText(i18n("Files scanned: %1").arg(filesscanned));
@@ -282,20 +282,20 @@ void ScanViewer::slotScan(const TQStringList & filepattern, int mode, bool recur
     TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
 
     if(( args->isSet( "scanthis" ) ) || (dcopscan)) {
-        calculateTime = FALSE;
-        showProgress = FALSE;
+        calculateTime = false;
+        showProgress = false;
         scan_time->hide();
         status2_label->show();
 
     }else{
-        calculateTime = TRUE;
-        showProgress = TRUE;
+        calculateTime = true;
+        showProgress = true;
         scan_time->show();
         status2_label->hide();
     }
 
-    scanCancelled = FALSE;
-    scanInProgress = FALSE;
+    scanCancelled = false;
+    scanInProgress = false;
 
     m_mode = mode;
     m_filepattern = filepattern;
@@ -332,7 +332,7 @@ void ScanViewer::slotScan(const TQStringList & filepattern, int mode, bool recur
     }
     //kdDebug() << scanCancelled << endl;
 
-    calculateTime = FALSE;
+    calculateTime = false;
     if (scanCancelled)
         return;
 
@@ -349,7 +349,7 @@ void ScanViewer::slotScan(const TQStringList & filepattern, int mode, bool recur
     slotClear();
     QuarantineList.clear();
 
-    errorsEncountered = FALSE;
+    errorsEncountered = false;
     filesscanned = 0;
     //status2_label->setText(i18n("Scan in Progress..."));
 
@@ -480,8 +480,8 @@ void ScanViewer::slotScan(const TQStringList & filepattern, int mode, bool recur
     }
 
     childproc = new KProcIO();
-    childproc->setUseShell(TRUE);
-    childproc->setUsePty (KProcIO::Stdout,TRUE);
+    childproc->setUseShell(true);
+    childproc->setUsePty (KProcIO::Stdout,true);
 
     if(clamdscan) {
 	config->setGroup("KlamavBackend");
@@ -521,9 +521,9 @@ void ScanViewer::slotScan(const TQStringList & filepattern, int mode, bool recur
     connect( childproc, TQ_SIGNAL(processExited(TDEProcess *)),
             TQ_SLOT(childExited()) );
 
-    scanInProgress = TRUE;
+    scanInProgress = true;
 
-    menu->setEnabled(FALSE);
+    menu->setEnabled(false);
 
 
 }
@@ -543,11 +543,11 @@ void ScanViewer::finish()
         kdDebug() << "deleted childproc" << endl;
     }
 
-    scanInProgress = FALSE;
+    scanInProgress = false;
 
     status_label->setText(i18n( "If viruses were found, you can right-click to quarantine selected files." ));
-    menu->setEnabled(TRUE);
-    //dir_combo->setEnabled(TRUE);
+    menu->setEnabled(true);
+    //dir_combo->setEnabled(true);
 
     scan_time->hide();
     prog->hide();
@@ -555,8 +555,8 @@ void ScanViewer::finish()
     progosd->saveSettings(TDEGlobal::config());
     status2_label->show();
 
-    multiScan = FALSE;
-    calculateTime = FALSE;
+    multiScan = false;
+    calculateTime = false;
 
     emit scanFinished(this);
 
@@ -566,7 +566,7 @@ void ScanViewer::finish()
 void ScanViewer::slotCancel()
 {
 
-    scanCancelled = TRUE;
+    scanCancelled = true;
     finish();
 
     //status2_frame->adjustSize();
@@ -686,7 +686,7 @@ void ScanViewer::slotClear()
 // }
 
 void  ScanViewer::Quarantine(){
-    bool allQuarantined=TRUE;
+    bool allQuarantined=true;
     config->setGroup("Kuarantine");
     TQStringList lastQuarLocations = config->readListEntry("KuarantineLocations");
 
@@ -710,7 +710,7 @@ void  ScanViewer::Quarantine(){
         TQString itemName = item2.mid((fnameEndPoint+1),((dtStartPoint+1) - (fnameEndPoint+2)));
         TQString when = item2.mid((dtStartPoint+1),(item2.length() - (dtStartPoint+1)));
         if (!(fname.isEmpty())){
-            TQStringList tokens = TQStringList::split ( "/", fname, FALSE );
+            TQStringList tokens = TQStringList::split ( "/", fname, false );
             TQString qname = tokens.last();
             qname.prepend("/");
             qname.prepend(quarloc);
@@ -826,7 +826,7 @@ void ScanViewer::slotTrendMicro()
 
 void ScanViewer::slotStartAgain()
 {
-    calculateTime = TRUE;
+    calculateTime = true;
     emit scanStartingAgain(this);
     slotScan(m_filepattern, m_mode, m_recursive,false);
 
@@ -840,8 +840,8 @@ bool ScanViewer::scanGoingOn()
 
 void ScanViewer::slotCancelScanTime()
 {
-    calculateTime = FALSE;
-    showProgress = FALSE;
+    calculateTime = false;
+    showProgress = false;
     status2_label->show();
     scan_time->hide();
 
@@ -923,7 +923,7 @@ void ScanViewer::startProgressDialog( const TQString & text )
     timer = new TQTimer( this );
     connect( timer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotProg() ) );
 
-    timer->start( 200, FALSE );
+    timer->start( 200, false );
 }
 
 void ScanViewer::slotProg()
